mailr9906 - /1.3/specific_fns/api_base.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on November 24, 2009 - 11:56:
Author: bugman
Date: Tue Nov 24 11:56:47 2009
New Revision: 9906

URL: http://svn.gna.org/viewcvs/relax?rev=9906&view=rev
Log:
Added create_mc_data() to the specific analysis API.


Modified:
    1.3/specific_fns/api_base.py

Modified: 1.3/specific_fns/api_base.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/specific_fns/api_base.py?rev=9906&r1=9905&r2=9906&view=diff
==============================================================================
--- 1.3/specific_fns/api_base.py (original)
+++ 1.3/specific_fns/api_base.py Tue Nov 24 11:56:47 2009
@@ -62,7 +62,7 @@
 
 
     def calculate(self, spin_id=None, verbosity=None, sim_index=None):
         """Calculation of the model-free chi-squared value.
 
         @keyword spin_id:   The spin identification string.
         @type spin_id:      str
@@ -72,8 +72,23 @@
         @type sim_index:    int
         """
 
+        # Not implemented.
         raise RelaxImplementError
  
+
+    def create_mc_data(self, spin_id=None):
+        """Prototype method for creating the Monte Carlo data.
+
+        @param spin_id: The spin identification string, as yielded by the 
base_data_loop() generator
+                        method.
+        @type spin_id:  str
+        @return:        The Monte Carlo data.
+        @rtype:         list of floats
+        """
+
+        # Not implemented.
+        raise RelaxImplementError
+
 
     def data_init(self, spin):
         """Dummy method for initialising the spin specific data structures.
@@ -62,7 +62,7 @@
 
     def calculate(self, spin_id=None, verbosity=None, sim_index=None):
-        """Calculation of the model-free chi-squared value.
+        """Prototype method for the calculation of the chi-squared value.
 
         @keyword spin_id:   The spin identification string.




Related Messages


Powered by MHonArc, Updated Tue Nov 24 12:20:01 2009